summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/formIO.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/formIO.cpp')
-rw-r--r--kexi/formeditor/formIO.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kexi/formeditor/formIO.cpp b/kexi/formeditor/formIO.cpp
index 503814d5..298c07f8 100644
--- a/kexi/formeditor/formIO.cpp
+++ b/kexi/formeditor/formIO.cpp
@@ -177,7 +177,7 @@ FormIO::saveFormToDom(Form *form, TQDomDocument &domDoc)
// We create the top class element
TQDomElement baseClass = domDoc.createElement("class");
uiElement.appendChild(baseClass);
- TQDomText baseClassV = domDoc.createTextNode(TQWIDGET_OBJECT_NAME_STRING);
+ TQDomText baseClassV = domDoc.createTextNode("TQWidget");
baseClass.appendChild(baseClassV);
// Save the toplevel widgets, and so the whole Form
@@ -952,11 +952,11 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
}
if(!item->parent()) // Toplevel widget
- tclass.setAttribute("class", TQWIDGET_OBJECT_NAME_STRING);
- // For compatibility, HBox, VBox and Grid are saved as TQLAYOUTWIDGET_OBJECT_NAME_STRING
+ tclass.setAttribute("class", "TQWidget");
+ // For compatibility, HBox, VBox and Grid are saved as "TQLayoutWidget"
else if(item->widget()->isA("HBox") || item->widget()->isA("VBox") || item->widget()->isA("Grid")
|| item->widget()->isA("HFlow") || item->widget()->isA("VFlow"))
- tclass.setAttribute("class", TQLAYOUTWIDGET_OBJECT_NAME_STRING);
+ tclass.setAttribute("class", "TQLayoutWidget");
else if(item->widget()->isA("CustomWidget"))
tclass.setAttribute("class", item->className());
else // Normal widgets
@@ -983,7 +983,7 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
savePropertyValue(tclass, domDoc, "geometry", item->widget()->property("geometry"), item->widget());
// Save the buddy widget for a label
- if(item->widget()->inherits(TQLABEL_OBJECT_NAME_STRING) && ((TQLabel*)item->widget())->buddy())
+ if(item->widget()->inherits("TQLabel") && ((TQLabel*)item->widget())->buddy())
savePropertyElement(tclass, domDoc, "property", "buddy", ((TQLabel*)item->widget())->buddy()->name());
// We save every property in the modifProp list of the ObjectTreeItem
@@ -1141,7 +1141,7 @@ FormIO::loadWidget(Container *container, const TQDomElement &el, TQWidget *paren
// We translate some name (for compatibility)
if(el.tagName() == "spacer")
classname = "Spring";
- else if(el.attribute("class") == TQLAYOUTWIDGET_OBJECT_NAME_STRING)
+ else if(el.attribute("class") == "TQLayoutWidget")
{
for(TQDomNode n = el.firstChild(); !n.isNull(); n = n.nextSibling())
{